==> cloudera-airflow-provider-2.1.2.tar.gz: cloudera-airflow-provider-2.1.2/cloudera/cdp/airflow/__init__.py <==
#  Cloudera Airflow Provider
#  (C) Cloudera, Inc. 2021-2022
#  All rights reserved.
#  Applicable Open Source License: Apache License Version 2.0
#
#  NOTE: Cloudera open source products are modular software products
#  made up of hundreds of individual components, each of which was
#  individually copyrighted.  Each Cloudera open source product is a
#  collective work under U.S. Copyright Law. Your license to use the
#  collective work is as provided in your written agreement with
#  Cloudera.  Used apart from the collective work, this file is
#  licensed for your use pursuant to the open source license
#  identified above.
#
#  This code is provided to you pursuant a written agreement with
#  (i) Cloudera, Inc. or (ii) a third-party authorized to distribute
#  this code. If you do not have a written agreement with Cloudera nor
#  with an authorized and properly licensed third party, you do not
#  have any rights to access nor to use this code.
#
#  Absent a written agreement with Cloudera, Inc. (“Cloudera”) to the
#  contrary, A) CLOUDERA PROVIDES THIS CODE TO YOU WITHOUT WARRANTIES OF ANY
#  KIND; (B) CLOUDERA DISCLAIMS ANY AND ALL EXPRESS AND IMPLIED
#  WARRANTIES WITH RESPECT TO THIS CODE, INCLUDING BUT NOT LIMITED TO
#  IMPLIED WARRANTIES OF TITLE, NON-INFRINGEMENT, MERCHANTABILITY AND
#  FITNESS FOR A PARTICULAR PURPOSE; (C) CLOUDERA IS NOT LIABLE TO YOU,
#  AND WILL NOT DEFEND, INDEMNIFY, NOR HOLD YOU HARMLESS FOR ANY CLAIMS
#  ARISING FROM OR RELATED TO THE CODE; AND (D)WITH RESPECT TO YOUR EXERCISE
#  OF ANY RIGHTS GRANTED TO YOU FOR THE CODE, CLOUDERA IS NOT LIABLE FOR ANY
#  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR
#  CONSEQUENTIAL DAMAGES INCLUDING, BUT NOT LIMITED TO, DAMAGES
#  RELATED TO LOST REVENUE, LOST PROFITS, LOSS OF INCOME, LOSS OF
#  BUSINESS ADVANTAGE OR UNAVAILABILITY, OR LOSS OR CORRUPTION OF
#  DATA.

"""Helper function for the package installation"""


def get_provider_info():  # pragma: no cover , metadata only used for building
    """Provides required metadata for the entrypoint in the setup.cfg"""
    return {
        "package-name": "cloudera-airflow-provider",
        "name": ("Cloudera Airflow Provider"),
        "description": """Provides Operators for running jobs on CDE and CDW.
Notes:
    - For Airflow 2.x a new dedicated connection type for CDE is available in the UI""",
        # hook-class-names is deprecated as of Airflow 2.2.0, keeping it for backwards compatibility with older versions
        # https://airflow.apache.org/docs/apache-airflow-providers/index.html#how-to-create-your-own-provider
        "hook-class-names": [
            "cloudera.airflow.providers.hooks.cde.CdeHook",
        ],
        "connection-types": [
            {
                "hook-class-name": "cloudera.airflow.providers.hooks.cde.CdeHook",
                "connection-type": "cloudera_data_engineering",
            }
        ],
        "versions": [
            "2.0.0",
            "1.1.0",
            "1.0.2",
            "1.0.1",
            "1.0.0",
        ],
    }

==> cloudera-airflow-provider-2.1.4.tar.gz: cloudera-airflow-provider-2.1.4/cloudera/cdp/airflow/__init__.py <==
#  Cloudera Airflow Provider
#  (C) Cloudera, Inc. 2021-2022
#  All rights reserved.
#  Applicable Open Source License: Apache License Version 2.0
#
#  NOTE: Cloudera open source products are modular software products
#  made up of hundreds of individual components, each of which was
#  individually copyrighted.  Each Cloudera open source product is a
#  collective work under U.S. Copyright Law. Your license to use the
#  collective work is as provided in your written agreement with
#  Cloudera.  Used apart from the collective work, this file is
#  licensed for your use pursuant to the open source license
#  identified above.
#
#  This code is provided to you pursuant a written agreement with
#  (i) Cloudera, Inc. or (ii) a third-party authorized to distribute
#  this code. If you do not have a written agreement with Cloudera nor
#  with an authorized and properly licensed third party, you do not
#  have any rights to access nor to use this code.
#
#  Absent a written agreement with Cloudera, Inc. (“Cloudera”) to the
#  contrary, A) CLOUDERA PROVIDES THIS CODE TO YOU WITHOUT WARRANTIES OF ANY
#  KIND; (B) CLOUDERA DISCLAIMS ANY AND ALL EXPRESS AND IMPLIED
#  WARRANTIES WITH RESPECT TO THIS CODE, INCLUDING BUT NOT LIMITED TO
#  IMPLIED WARRANTIES OF TITLE, NON-INFRINGEMENT, MERCHANTABILITY AND
#  FITNESS FOR A PARTICULAR PURPOSE; (C) CLOUDERA IS NOT LIABLE TO YOU,
#  AND WILL NOT DEFEND, INDEMNIFY, NOR HOLD YOU HARMLESS FOR ANY CLAIMS
#  ARISING FROM OR RELATED TO THE CODE; AND (D)WITH RESPECT TO YOUR EXERCISE
#  OF ANY RIGHTS GRANTED TO YOU FOR THE CODE, CLOUDERA IS NOT LIABLE FOR ANY
#  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR
#  CONSEQUENTIAL DAMAGES INCLUDING, BUT NOT LIMITED TO, DAMAGES
#  RELATED TO LOST REVENUE, LOST PROFITS, LOSS OF INCOME, LOSS OF
#  BUSINESS ADVANTAGE OR UNAVAILABILITY, OR LOSS OR CORRUPTION OF
#  DATA.

"""Helper function for the package installation"""


def get_provider_info():  # pragma: no cover , metadata only used for building
    """Provides required metadata for the entrypoint in the setup.cfg"""
    return {
        "package-name": "cloudera-airflow-provider",
        "name": ("Cloudera Airflow Provider"),
        "description": """Provides Operators for running jobs on CDE and CDW.
Notes:
    - For Airflow 2.x a new dedicated connection type for CDE is available in the UI""",
        # hook-class-names is deprecated as of Airflow 2.2.0,
        # keeping it for backwards compatibility with older versions
        # https://airflow.apache.org/docs/apache-airflow-providers/index.html#how-to-create-your-own-provider
        "hook-class-names": [
            "cloudera.airflow.providers.hooks.cde.CdeHook",
        ],
        "connection-types": [
            {
                "hook-class-name": "cloudera.airflow.providers.hooks.cde.CdeHook",
                "connection-type": "cloudera_data_engineering",
            }
        ],
        "task-decorators": [
            {
                "name": "cde",
                "class-name": "cloudera.airflow.providers.decorators.cde.cde_task",
            }
        ],
        "versions": [
            "2.0.0",
            "1.1.0",
            "1.0.2",
            "1.0.1",
            "1.0.0",
        ],
    }
